/**
 * File navigation.js.
 *
 * Handles toggling the navigation menu for small screens and enables TAB key
 * navigation support for dropdown menus.
 */
( function() {
    var cutewp_secondary_container, cutewp_secondary_button, cutewp_secondary_menu, cutewp_secondary_links, cutewp_secondary_i, cutewp_secondary_len;

    cutewp_secondary_container = document.getElementById( 'cutewp-secondary-navigation' );
    if ( ! cutewp_secondary_container ) {
        return;
    }

    cutewp_secondary_button = cutewp_secondary_container.getElementsByTagName( 'button' )[0];
    if ( 'undefined' === typeof cutewp_secondary_button ) {
        return;
    }

    cutewp_secondary_menu = cutewp_secondary_container.getElementsByTagName( 'ul' )[0];

    // Hide menu toggle button if menu is empty and return early.
    if ( 'undefined' === typeof cutewp_secondary_menu ) {
        cutewp_secondary_button.style.display = 'none';
        return;
    }

    cutewp_secondary_menu.setAttribute( 'aria-expanded', 'false' );
    if ( -1 === cutewp_secondary_menu.className.indexOf( 'nav-menu' ) ) {
        cutewp_secondary_menu.className += ' nav-menu';
    }

    cutewp_secondary_button.onclick = function() {
        if ( -1 !== cutewp_secondary_container.className.indexOf( 'cutewp-toggled' ) ) {
            cutewp_secondary_container.className = cutewp_secondary_container.className.replace( ' cutewp-toggled', '' );
            cutewp_secondary_button.setAttribute( 'aria-expanded', 'false' );
            cutewp_secondary_menu.setAttribute( 'aria-expanded', 'false' );
        } else {
            cutewp_secondary_container.className += ' cutewp-toggled';
            cutewp_secondary_button.setAttribute( 'aria-expanded', 'true' );
            cutewp_secondary_menu.setAttribute( 'aria-expanded', 'true' );
        }
    };

    // Get all the link elements within the menu.
    cutewp_secondary_links    = cutewp_secondary_menu.getElementsByTagName( 'a' );

    // Each time a menu link is focused or blurred, toggle focus.
    for ( cutewp_secondary_i = 0, cutewp_secondary_len = cutewp_secondary_links.length; cutewp_secondary_i < cutewp_secondary_len; cutewp_secondary_i++ ) {
        cutewp_secondary_links[cutewp_secondary_i].addEventListener( 'focus', cutewp_secondary_toggleFocus, true );
        cutewp_secondary_links[cutewp_secondary_i].addEventListener( 'blur', cutewp_secondary_toggleFocus, true );
    }

    /**
     * Sets or removes .focus class on an element.
     */
    function cutewp_secondary_toggleFocus() {
        var self = this;

        // Move up through the ancestors of the current link until we hit .nav-menu.
        while ( -1 === self.className.indexOf( 'nav-menu' ) ) {

            // On li elements toggle the class .focus.
            if ( 'li' === self.tagName.toLowerCase() ) {
                if ( -1 !== self.className.indexOf( 'cutewp-focus' ) ) {
                    self.className = self.className.replace( ' cutewp-focus', '' );
                } else {
                    self.className += ' cutewp-focus';
                }
            }

            self = self.parentElement;
        }
    }

    /**
     * Toggles `focus` class to allow submenu access on tablets.
     */
    ( function( cutewp_secondary_container ) {
        var touchStartFn, cutewp_secondary_i,
            parentLink = cutewp_secondary_container.querySelectorAll( '.menu-item-has-children > a, .page_item_has_children > a' );

        if ( 'ontouchstart' in window ) {
            touchStartFn = function( e ) {
                var menuItem = this.parentNode, cutewp_secondary_i;

                if ( ! menuItem.classList.contains( 'cutewp-focus' ) ) {
                    e.preventDefault();
                    for ( cutewp_secondary_i = 0; cutewp_secondary_i < menuItem.parentNode.children.length; ++cutewp_secondary_i ) {
                        if ( menuItem === menuItem.parentNode.children[cutewp_secondary_i] ) {
                            continue;
                        }
                        menuItem.parentNode.children[cutewp_secondary_i].classList.remove( 'cutewp-focus' );
                    }
                    menuItem.classList.add( 'cutewp-focus' );
                } else {
                    menuItem.classList.remove( 'cutewp-focus' );
                }
            };

            for ( cutewp_secondary_i = 0; cutewp_secondary_i < parentLink.length; ++cutewp_secondary_i ) {
                parentLink[cutewp_secondary_i].addEventListener( 'touchstart', touchStartFn, false );
            }
        }
    }( cutewp_secondary_container ) );
} )();


( function() {
    var cutewp_primary_container, cutewp_primary_button, cutewp_primary_menu, cutewp_primary_links, cutewp_primary_i, cutewp_primary_len;

    cutewp_primary_container = document.getElementById( 'cutewp-primary-navigation' );
    if ( ! cutewp_primary_container ) {
        return;
    }

    cutewp_primary_button = cutewp_primary_container.getElementsByTagName( 'button' )[0];
    if ( 'undefined' === typeof cutewp_primary_button ) {
        return;
    }

    cutewp_primary_menu = cutewp_primary_container.getElementsByTagName( 'ul' )[0];

    // Hide menu toggle button if menu is empty and return early.
    if ( 'undefined' === typeof cutewp_primary_menu ) {
        cutewp_primary_button.style.display = 'none';
        return;
    }

    cutewp_primary_menu.setAttribute( 'aria-expanded', 'false' );
    if ( -1 === cutewp_primary_menu.className.indexOf( 'nav-menu' ) ) {
        cutewp_primary_menu.className += ' nav-menu';
    }

    cutewp_primary_button.onclick = function() {
        if ( -1 !== cutewp_primary_container.className.indexOf( 'cutewp-toggled' ) ) {
            cutewp_primary_container.className = cutewp_primary_container.className.replace( ' cutewp-toggled', '' );
            cutewp_primary_button.setAttribute( 'aria-expanded', 'false' );
            cutewp_primary_menu.setAttribute( 'aria-expanded', 'false' );
        } else {
            cutewp_primary_container.className += ' cutewp-toggled';
            cutewp_primary_button.setAttribute( 'aria-expanded', 'true' );
            cutewp_primary_menu.setAttribute( 'aria-expanded', 'true' );
        }
    };

    // Get all the link elements within the menu.
    cutewp_primary_links    = cutewp_primary_menu.getElementsByTagName( 'a' );

    // Each time a menu link is focused or blurred, toggle focus.
    for ( cutewp_primary_i = 0, cutewp_primary_len = cutewp_primary_links.length; cutewp_primary_i < cutewp_primary_len; cutewp_primary_i++ ) {
        cutewp_primary_links[cutewp_primary_i].addEventListener( 'focus', cutewp_primary_toggleFocus, true );
        cutewp_primary_links[cutewp_primary_i].addEventListener( 'blur', cutewp_primary_toggleFocus, true );
    }

    /**
     * Sets or removes .focus class on an element.
     */
    function cutewp_primary_toggleFocus() {
        var self = this;

        // Move up through the ancestors of the current link until we hit .nav-menu.
        while ( -1 === self.className.indexOf( 'nav-menu' ) ) {

            // On li elements toggle the class .focus.
            if ( 'li' === self.tagName.toLowerCase() ) {
                if ( -1 !== self.className.indexOf( 'cutewp-focus' ) ) {
                    self.className = self.className.replace( ' cutewp-focus', '' );
                } else {
                    self.className += ' cutewp-focus';
                }
            }

            self = self.parentElement;
        }
    }

    /**
     * Toggles `focus` class to allow submenu access on tablets.
     */
    ( function( cutewp_primary_container ) {
        var touchStartFn, cutewp_primary_i,
            parentLink = cutewp_primary_container.querySelectorAll( '.menu-item-has-children > a, .page_item_has_children > a' );

        if ( 'ontouchstart' in window ) {
            touchStartFn = function( e ) {
                var menuItem = this.parentNode, cutewp_primary_i;

                if ( ! menuItem.classList.contains( 'cutewp-focus' ) ) {
                    e.preventDefault();
                    for ( cutewp_primary_i = 0; cutewp_primary_i < menuItem.parentNode.children.length; ++cutewp_primary_i ) {
                        if ( menuItem === menuItem.parentNode.children[cutewp_primary_i] ) {
                            continue;
                        }
                        menuItem.parentNode.children[cutewp_primary_i].classList.remove( 'cutewp-focus' );
                    }
                    menuItem.classList.add( 'cutewp-focus' );
                } else {
                    menuItem.classList.remove( 'cutewp-focus' );
                }
            };

            for ( cutewp_primary_i = 0; cutewp_primary_i < parentLink.length; ++cutewp_primary_i ) {
                parentLink[cutewp_primary_i].addEventListener( 'touchstart', touchStartFn, false );
            }
        }
    }( cutewp_primary_container ) );
} )();